@@ -16,9 +16,11 @@ sub _parse {
         return Spreadsheet::HTML::File::JSON::_parse( $args );
     } elsif ($file =~ /\.ya?ml$/) {
         return Spreadsheet::HTML::File::YAML::_parse( $args );
+    } elsif ($file =~ /\.(gif|png|jpe?g)$/) {
+        return Spreadsheet::HTML::File::Image::_parse( $args );
     }
 
-    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
+    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file or $file eq '-';
     return [[ "cannot load $file" ],[ 'please install Spreadsheet::Read' ]] if $NOT_AVAILABLE;
 
     my $workbook = ReadData( $file,
@@ -32,6 +34,8 @@ sub _parse {
         parser  => $args->{parser},
     );
 
+    close $file if ref($file) eq 'GLOB';
+
     my $parsed = $workbook->[ $args->{worksheet} ];
 
     if ($args->{preserve} and ref $parsed->{attr} eq 'ARRAY' and scalar@{$parsed->{attr}}) {
@@ -123,6 +127,25 @@ Parses with (requires) L<YAML>.
   generate( file => 'foo.yml' )
   generate( file => 'foo.yaml' )
 
+=item * JPEG
+
+Parses with (requires) L<Imager::File::JPEG>.
+
+  generate( file => 'foo.jpg' )
+  generate( file => 'foo.jpeg' )
+
+=item * PNG
+
+Parses with (requires) L<Imager::File::PNG>.
+
+  generate( file => 'foo.png' )
+
+=item * GIF
+
+Parses with (requires) L<Imager::File::GIF>.
+
+  generate( file => 'foo.gif' )
+
 =back
 
 =head1 SEE ALSO
@@ -212,6 +235,65 @@ sub _parse {
 
 
 
+package Spreadsheet::HTML::File::Image;
+use Carp;
+use strict;
+use warnings FATAL => 'all';
+
+eval "use Imager";
+our $NOT_AVAILABLE = $@;
+
+sub _parse {
+    my $args = shift;
+    my $file = $args->{file};
+    return [[ "cannot load $file" ],[ 'No such file or directory' ]] unless -r $file;
+    return [[ "cannot load $file" ],[ 'please install Imager' ]] if $NOT_AVAILABLE;
+
+    my $imager = Imager->new;
+    my $image  = $imager->read( file => $file ) or return [[ "cannot load $file" ],[ $imager->errstr ]];
+
+    $args->{block} = $args->{block} && $args->{block} =~ /\D/ ? 8 : ($args->{block} || 0) < 2 ? 8 : $args->{block};
+    $args->{fill}  = join( 'x', int( $image->getheight / $args->{block} ), int( $image->getwidth / $args->{block} ) );
+    $args->{table} = { cellspacing => 0, border => 0, cellpadding => 0 };
+
+    my $r = 0;
+    for (my $x = 0; $x < $image->getwidth; $x += $args->{block}) {
+        my $c = 0;
+        for (my $y = 0; $y < $image->getheight; $y += $args->{block}) {
+            
+            my (@x,@y);
+            for my $i ($x .. $x + $args->{block}) {
+                for my $j ($y .. $y + $args->{block}) {
+                    push @x, $i;
+                    push @y, $j;
+                }
+            }
+
+            my %block;
+            for my $pixel ($image->getpixel( x => \@x, y => \@y )) {
+                next unless ref $pixel;
+                my $color = '#' . join '', map sprintf( "%02X", $_ ), ($pixel->rgba)[0..2];
+                $block{$color}++;
+            }
+
+            my $color = (sort { $block{$b} <=> $block{$a} } keys %block)[0];
+            $args->{"-r${c}c${r}"} = {
+                width  => $args->{block} * 2,
+                height => $args->{block},
+                style  => { 'background-color' => $color },
+            };
+            $c++;
+        }
+        $r++;
+    }
+
+    return [];
+}
+
+1;
+
+
+
 =head1 AUTHOR
 
 Jeff Anderson, C<< <jeffa at cpan.org> >>
